==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/QrtzJobDetailsKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.enums.GrupaZadania;
import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class QrtzJobDetailsKey extends GenericDPSObject {
    /**
     * QRTZ_JOB_DETAILS.SCHED_NAME
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String schedName;

    /**
     * QRTZ_JOB_DETAILS.JOB_NAME
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String jobName;

    /**
     * QRTZ_JOB_DETAILS.JOB_GROUP
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private GrupaZadania jobGroup;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return QRTZ_JOB_DETAILS.SCHED_NAME
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getSchedName() {
        return schedName;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:40
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * QRTZ_JOB_DETAILS.SCHED_NAME
     *
     * @param schedName
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSchedName(String schedName) {
        this.schedName = schedName == null ? null : schedName.trim();
    }

    /**
     * @return QRTZ_JOB_DETAILS.JOB_NAME
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getJobName() {
        return jobName;
    }

    /**
     * QRTZ_JOB_DETAILS.JOB_NAME
     *
     * @param jobName
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setJobName(String jobName) {
        this.jobName = jobName == null ? null : jobName.trim();
    }

    /**
     * @return QRTZ_JOB_DETAILS.JOB_GROUP
     * @mbggenerated 2014-03-10 10:45:37
     */
    public GrupaZadania getJobGroup() {
        return jobGroup;
    }

    /**
     * QRTZ_JOB_DETAILS.JOB_GROUP
     *
     * @param jobGroup
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setJobGroup(GrupaZadania jobGroup) {
        this.jobGroup = jobGroup;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        QrtzJobDetailsKey other = (QrtzJobDetailsKey) that;
        return (this.getSchedName() == null ? other.getSchedName() == null : this.getSchedName().equals(other.getSchedName()))
            && (this.getJobName() == null ? other.getJobName() == null : this.getJobName().equals(other.getJobName()))
            && (this.getJobGroup() == null ? other.getJobGroup() == null : this.getJobGroup().equals(other.getJobGroup()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getSchedName() == null) ? 0 : getSchedName().hashCode());
        result = prime * result + ((getJobName() == null) ? 0 : getJobName().hashCode());
        result = prime * result + ((getJobGroup() == null) ? 0 : getJobGroup().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", schedName=").append(schedName);
        sb.append(", jobName=").append(jobName);
        sb.append(", jobGroup=").append(jobGroup);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/QrtzJobDetailsKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.enums.GrupaZadania;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class QrtzJobDetailsKey extends GenericDPSObject {
    /**
     * QRTZ_JOB_DETAILS.SCHED_NAME
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String schedName;

    /**
     * QRTZ_JOB_DETAILS.JOB_NAME
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String jobName;

    /**
     * QRTZ_JOB_DETAILS.JOB_GROUP
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private GrupaZadania jobGroup;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return QRTZ_JOB_DETAILS.SCHED_NAME
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getSchedName() {
        return schedName;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:44
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * QRTZ_JOB_DETAILS.SCHED_NAME
     *
     * @param schedName
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSchedName(String schedName) {
        this.schedName = schedName == null ? null : schedName.trim();
    }

    /**
     * @return QRTZ_JOB_DETAILS.JOB_NAME
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getJobName() {
        return jobName;
    }

    /**
     * QRTZ_JOB_DETAILS.JOB_NAME
     *
     * @param jobName
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setJobName(String jobName) {
        this.jobName = jobName == null ? null : jobName.trim();
    }

    /**
     * @return QRTZ_JOB_DETAILS.JOB_GROUP
     * @mbggenerated 2014-03-13 16:02:38
     */
    public GrupaZadania getJobGroup() {
        return jobGroup;
    }

    /**
     * QRTZ_JOB_DETAILS.JOB_GROUP
     *
     * @param jobGroup
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setJobGroup(GrupaZadania jobGroup) {
        this.jobGroup = jobGroup;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        QrtzJobDetailsKey other = (QrtzJobDetailsKey) that;
        return (this.getSchedName() == null ? other.getSchedName() == null : this.getSchedName().equals(other.getSchedName()))
            && (this.getJobName() == null ? other.getJobName() == null : this.getJobName().equals(other.getJobName()))
            && (this.getJobGroup() == null ? other.getJobGroup() == null : this.getJobGroup().equals(other.getJobGroup()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getSchedName() == null) ? 0 : getSchedName().hashCode());
        result = prime * result + ((getJobName() == null) ? 0 : getJobName().hashCode());
        result = prime * result + ((getJobGroup() == null) ? 0 : getJobGroup().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", schedName=").append(schedName);
        sb.append(", jobName=").append(jobName);
        sb.append(", jobGroup=").append(jobGroup);
        sb.append("]");
        return sb.toString();
    }
}
